import {
    SciChartSurface
} from "scichart/Charting/Visuals/SciChartSurface";
import {
    NumericAxis
} from "scichart/Charting/Visuals/Axis/NumericAxis";
import {
    XyDataSeries
} from "scichart/Charting/Model/XyDataSeries";
import {
    FastLineRenderableSeries
} from "scichart/Charting/Visuals/RenderableSeries/FastLineRenderableSeries";
import {
    EAxisAlignment
} from "scichart/types/AxisAlignment";
import {
    EllipsePointMarker
} from "scichart/Charting/Visuals/PointMarkers/EllipsePointMarker";
import {
    NumberRange
} from "scichart/Core/NumberRange";
import { RolloverModifier } from "scichart/Charting/ChartModifiers/RolloverModifier";


async function initSciChart() {
    const a = [];
    a[0] = await SciChartSurface.create("scichart-root");
    a[1] = await SciChartSurface.create("scichart-root2");
    a[2] = await SciChartSurface.create("scichart-root3");

    a[0].sciChartSurface.xAxes.add(new NumericAxis(a[0].wasmContext, {
        growBy: new NumberRange(0.1, 0.1),
        axisAlignment: EAxisAlignment.Left,
        flippedCoordinates: false,
    }));
    a[0].sciChartSurface.yAxes.add(new NumericAxis(a[0].wasmContext, {
        axisAlignment: EAxisAlignment.Top,
        flippedCoordinates: true,
        growBy: new NumberRange(0.1, 0.1),
    }));
    a[1].sciChartSurface.xAxes.add(new NumericAxis(a[1].wasmContext, {
        growBy: new NumberRange(0.1, 0.1),
        axisAlignment: EAxisAlignment.Left,
        flippedCoordinates: false,
        drawLabels: false
    }));
    a[1].sciChartSurface.yAxes.add(new NumericAxis(a[1].wasmContext, {
        axisAlignment: EAxisAlignment.Top,
        flippedCoordinates: true,
        growBy: new NumberRange(0.1, 0.1)
    }));
    a[2].sciChartSurface.xAxes.add(new NumericAxis(a[2].wasmContext, {
        growBy: new NumberRange(0.1, 0.1),
        axisAlignment: EAxisAlignment.Left,
        flippedCoordinates: false,
        drawLabels: false
    }));
    a[2].sciChartSurface.yAxes.add(new NumericAxis(a[2].wasmContext, {
        axisAlignment: EAxisAlignment.Top,
        flippedCoordinates: true,
        growBy: new NumberRange(0.1, 0.1)
    }));

    // Create a Line Series with XyDataSeries and some data
    const lineSeries1 = new FastLineRenderableSeries(a[0].wasmContext, {
        strokeThickness: 3,
        pointMarker: new EllipsePointMarker(a[0].wasmContext, {
            stroke: "White",
            fill: "White",
            width: 9,
            height: 9,
        }),
    });
    lineSeries1.dataSeries = new XyDataSeries(a[0].wasmContext, {
        dataSeriesName: "Line Series 1",
        xValues: [0, 1, 2, 3, 4, 5, 6, 7, 8, 9],
        yValues: [0, 1, 5, 1, 20, 5, 1, 8, 9, 3],
    });

    const lineSeries2 = new FastLineRenderableSeries(a[1].wasmContext, {
        strokeThickness: 3,
        pointMarker: new EllipsePointMarker(a[1].wasmContext, {
            stroke: "White",
            fill: "White",
            width: 9,
            height: 9,
        }),
    });
    lineSeries2.dataSeries = new XyDataSeries(a[1].wasmContext, {
        dataSeriesName: "Line Series 2",
        xValues: [0, 1, 2, 3, 4, 5, 6, 7, 8, 9],
        yValues: [0, 1, 5, 1, 20, 5, 1, 8, 9, 3],
    });

    const lineSeries3 = new FastLineRenderableSeries(a[2].wasmContext, {
        strokeThickness: 3,
        pointMarker: new EllipsePointMarker(a[2].wasmContext, {
            stroke: "White",
            fill: "White",
            width: 9,
            height: 9,
        }),
    });
    lineSeries3.dataSeries = new XyDataSeries(a[2].wasmContext, {
        dataSeriesName: "Line Series 3",
        xValues: [0, 1, 2, 3, 4, 5, 6, 7, 8, 9],
        yValues: [0, 1, 5, 1, 20, 5, 1, 8, 9, 3],
    });

    // Add the line series to the SciChartSurface
    a[0].sciChartSurface.renderableSeries.add(lineSeries1);
    a[1].sciChartSurface.renderableSeries.add(lineSeries2);
    a[2].sciChartSurface.renderableSeries.add(lineSeries3);

    const rolloverModifier1 = new RolloverModifier({
        modifierGroup: "group_1",
        showTooltip: false,
    });
    a[0].sciChartSurface.chartModifiers.add(
        rolloverModifier1
    );
    const rolloverModifier2 = new RolloverModifier({
        modifierGroup: "group_1",
        showTooltip: false,
    });
    a[1].sciChartSurface.chartModifiers.add(
        rolloverModifier2
    );
    const rolloverModifier3 = new RolloverModifier({
        modifierGroup: "group_1",
        showTooltip: false,
    });
    a[2].sciChartSurface.chartModifiers.add(
        rolloverModifier3
    );
}
initSciChart();